.. Django Menu Generator documentation master file, created by
   sphinx-quickstart on Wed Apr 26 22:30:34 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Menu Generator's documentation!
=================================================

Django Menu Generator is a productivity tool that enables the generation of full featured menus through python
dictionaries list, you only need to setup the HTML structure once for each menu you like to build and then use the
dictionaries to generate menu items

Features:
---------

-  Tested support to Python 3.4, 3.5, 3.6
-  Tested support to Django 1.8, 1.9, 1.10, 1.11, 2.0
-  No database
-  Support unlimited menus
-  Icons support
-  Semi-Automatically identifies the selected item and his breadcrums
-  Conditional menu items display through validators (Permissions,
   Authentications or whatever you want)

Contents:
---------

.. toctree::
   :maxdepth: 2

   install
   usage
   menugeneration
   urls
   validators
   changelog
   tests
   authors
   contribute
   support
   license
   credits
